---
name: Feature request
about: Suggest an idea to improve ``utilipy``
title: ''
labels: enhancement
assignees: ''

---

### Description
<!-- Provide a general description of the feature you would like. -->
<!-- If you want to, you can suggest a draft design or API. -->
<!-- This way we have a deeper discussion on the feature. -->


### Additional context
<!-- Add any other context or screenshots about the feature request here. -->
<!-- This part is optional. -->


### Checklist

- [ ]  Check out our [contributing guidelines](https://github.com/astropy/astropy/blob/master/CONTRIBUTING.md).
- [ ]  Check out our [code of conduct](https://github.com/astropy/astropy/blob/master/CODE_OF_CONDUCT.md).
- [ ]  Search the GitHub repository to see if a similar issue has already been posted. If a similar issue is closed, have a quick look to see if you are satisfied by the resolution. If not please go ahead and open an issue!
